@@ -22,7 +22,6 @@ def load_json(dest):
     except:
         return None
 
-path = "S:/all member/퀀트운용팀/93 QuickDB/"
 
 class QuickDB:
     def __init__(self, yqtb=None, fsdata=None, path=None):
@@ -46,15 +45,15 @@ class QuickDB:
 
     def getFS(self, account, date, tickers=None):
         result = {}
-        for ticker, yq in db.getYQ(date).dropna().iteritems():
-            result[ticker] = fsdata[yq][account].get(ticker)
+        for ticker, yq in self.getYQ(date).dropna().iteritems():
+            result[ticker] = self.fsdata[yq][account].get(ticker)
         if tickers is not None:
             return pd.Series(result)[tickers]
         else:
             return pd.Series(result)
 
     def getTradables(self, date):
-        return self.getTS(88, self).where(lambda x : x == 0).dropna()
+        return self.getTS(88, date).where(lambda x : x == 0).dropna()
 
     def _getTrailingYQ(self, yq, n=4):
         y,q = yq[:4], (yq[4:])
@@ -97,20 +96,18 @@ class QuickDB:
 
     def getTS(self, n, start:str, end:str=None):
         start = str(start)
+        if end is None:
+            end = start
         end = str(end)
         y1 = int(str(start)[:4])
         res = []
         try:
-            if end:
-                y2 = int(str(end)[:4])
-                for y in range(y1, y2+1):
-                    _ = load_pkl(os.path.join(self.path, f"data/{y}_{n}.data"))
-                    if _ is not None:
-                        res.append(_)
-                return pd.concat(res).sort_index().loc[start : end]
-            else:
-                return load_pkl(os.path.join(self.path, f'data/{y1}_{n}.data'))
+            y2 = int(str(end)[:4])
+            for y in range(y1, y2+1):
+                _ = load_pkl(os.path.join(self.path, f"data/{y}_{n}.data"))
+                if _ is not None:
+                    res.append(_)
+            return pd.concat(res).sort_index().loc[start : end]
             #.sort_index().drop_duplicates().loc[start:].iloc[0]
         except Exception as e:
-            print(e)
-            return None
\ No newline at end of file
+            raise e
\ No newline at end of file
